
## =============================================================================
## Notes
## =============================================================================

# Regression analysis relies on the script biv_mul_man.R and two functions: function_reg_table.R and function_trans_table.R
# 
# Tables are exported as csv-files. gtsummary has been tried, but performance and flexibility was not op to the task.
# Dependencies has been minimised to primarily use base-R and a tiny bit of dplyr.
# 
# Focus has been on universal functions, and the amount of flags has accumulated...
# 
# Only retransformation is performed on independent variables (these are not marked in the exported tables). 
# Coefs and CIs are transformed according to this: 
# https://stats.stackexchange.com/questions/93089/reporting-regression-statistics-after-logarithmic-transformation to allow for interpretation.

## =============================================================================
## Table 1
## =============================================================================

source("data_format.R")

source("table_1.R")

tbl_1

## =============================================================================
## Primary regression analysis
## =============================================================================

source("data_format.R")

outs<-c("mdi_1_enr","mdi_6_newobs_enr")

lbl_x <- NULL # Extra label in file name

inter_reg <- NULL # Interaction variables to include (only multivariate)

biv_mul <- TRUE # Sets flag for both bivariate and multivariate or only multivariate analysis 

strat_var <- NULL # Variable to stratify by. Only one variable(!)

trans_vars <- TRUE # Transform variables? T/F

sqrt_vars<-"pase_0" # Variables to sqrt-transfom
log1p_vars<-"nihss_0" # Variables to log1p-transform, not outcome
log_vars <- NULL # Variables to log-transform

log1p_vars_all<-c(log1p_vars,outs) # All variables to log1p-transform, incl outcome

trans_back <- TRUE # Back transform variables? T/F

print_tbl <- TRUE # Print tables? T/F

# source("biv_mul.R")

source("biv_mul_man.R")

export

# bm_16_tbl

strat_var <- "active_treat" # Variable to stratify by. Only one variable(!)

# source("biv_mul.R")
 
source("biv_mul_man.R")

export
# bm_16_tbl

## =============================================================================
## Sensitivity regression analysis
## =============================================================================

source("data_format.R")

outs<-c("mdi_1","mdi_6")

lbl_x <- "_sens" # Extra label in file name

inter_reg <- NULL # Interaction variables to include (only multivariate)

biv_mul <- TRUE # Sets flag for both bivariate and multivariate or only multivariate analysis 

strat_var <- NULL # Variable to stratify by. Only one variable(!)

trans_vars <- TRUE # Transform variables? T/F

sqrt_vars<-"pase_0" # Variables to sqrt-transfom
log1p_vars<-"nihss_0" # Variables to log1p-transform, not outcome
log_vars <- NULL # Variables to log-transform

log1p_vars_all<-c(log1p_vars,outs) # All variables to log1p-transform, incl outcome

trans_back <- TRUE # Back transform variables? T/F

print_tbl <- TRUE # Print tables? T/F

# source("biv_mul.R")

source("biv_mul_man.R")

# rbind("One month",bm_list[[1]][-1],"Six month",bm_list[[2]][-1])

# bm_16_tbl

strat_var <- "active_treat" # Variable to stratify by. Only one variable(!)

# source("biv_mul.R")

source("biv_mul_man.R")

# bm_16_tbl


## =============================================================================
## Interaction regression analysis
## =============================================================================

source("data_format.R")

outs<-c("mdi_1_enr","mdi_6_newobs_enr")

lbl_x <- "_inter" # Extra label in file name

inter_reg <- c("active_treat","pase_0") # Interaction variables to include (only multivariate)

biv_mul <- TRUE # Sets flag for both bivariate and multivariate or only multivariate analysis 

trans_vars <- TRUE # Transform variables? T/F

strat_var <- NULL # Variable to stratify by. Only one variable(!)

sqrt_vars<-"pase_0" # Variables to sqrt-transfom
log1p_vars<-"nihss_0" # Variables to log1p-transform, not outcome
log_vars <- NULL # Variables to log-transform

log1p_vars_all<-c(log1p_vars,outs) # All variables to log1p-transform, incl outcome

trans_back <- TRUE # Back transform variables? T/F

print_tbl <- TRUE # Print tables? T/F


# source("regression_interaction.R")

source("biv_mul_man.R")

export

## =============================================================================
## NIHSS~PASE0 regression analysis
## =============================================================================

source("data_format.R")

vars<-c("pase_0", # New variables for analysis
        "female",
        "age",
        "cohab",
        "ever_smoker",
        "diabetes", 
        "hypertension", 
        "afli", 
        "ami", 
        "tci",
        "pad")

outs<-c("nihss_0")

lbl_x <- "_nihss-pase" # Extra label in file name

inter_reg <- NULL # Interaction variables to include (only multivariate)

biv_mul <- FALSE # Sets flag for both bivariate and multivariate or only multivariate analysis 

trans_vars <- TRUE # Transform variables? T/F

strat_var <- NULL # Variable to stratify by. Only one variable(!)

sqrt_vars<-"pase_0" # Variables to sqrt-transfom
log1p_vars<-NULL # Variables to log1p-transform, not outcome
log_vars <- NULL # Variables to log-transform

log1p_vars_all<-c(outs) # All variables to log1p-transform, incl outcome

trans_back <- TRUE # Back transform variables? T/F

print_tbl <- TRUE # Print tables? T/F

# source("regression_nihss-pase.R")

source("biv_mul_man.R")

export

