## =============================================================================
## Requirements
## =============================================================================

source("function_trans_cols.R")

if (trans_vars==TRUE){
  # If trans_vars flag is TRUE, transform specified variables
  dta<-trans_cols(dta_backup,sqrts=sqrt_vars,log1ps = log1p_vars_all)
} else {dta<-dta_backup}

library(dplyr)
library(gtsummary)

source("function_back_trans.R")

## =============================================================================
## Loop
## =============================================================================

bm_list<-list()

for (i in 1:length(outs)){
  
  dta_l<-dta|>
    dplyr::select(all_of(c("active_treat",vars,outs[i]))) # active_treat should be vector
  
  sel<-dta_l|>
    sapply(is.factor)
  
  ## Bivariate
  if (!is.null(strat_var)){biv<-dta_l |>
    tbl_strata(
      strata = all_of(strat_var),
      .tbl_fun =
        ~ .x %>%
        tbl_uvregression(data=.,
                         y=outs[i],
                         method=lm,
                         label = lab_sel(labels_all,vars),
                         show_single_row=colnames(dta_l)[sel][-1], # excluding the first, active-treatment, as this is strat
                         estimate_fun = ~style_sigfig(.x,digits = 3),
                         pvalue_fun = ~style_pvalue(.x, digits = 3)
        )|> 
        add_global_p()|>
        bold_p() |>  
        bold_labels() |>
        italicize_levels(),
      .header = "**{strata}**, N = {n}"
    )
  } else {
    biv<-dta_l|>
      tbl_uvregression(data=_,
                       y=outs[i],
                       method=lm,
                       label = lab_sel(labels_all,vars),
                       show_single_row=colnames(dta_l)[sel],
                       estimate_fun = ~style_sigfig(.x,digits = 3),
                       pvalue_fun = ~style_pvalue(.x, digits = 3)
      )  |> 
      add_global_p()|>
      bold_p()
  }
  
  ## Multivariate
  if (!is.null(strat_var)){
    mul<-dta_l |>
      tbl_strata(
        strata = all_of(strat_var),
        .tbl_fun =
          ~ .x %>%
          lm(formula(paste(c(outs[i],"."),collapse="~")), 
             data = .) |> 
          tbl_regression(label = lab_sel(labels_all,vars),
                         show_single_row=colnames(dta_l)[sel][-1], # excluding the first, active-treatment, as this is strat
                         estimate_fun = ~style_sigfig(.x,digits = 3),
                         pvalue_fun = ~style_pvalue(.x, digits = 3)
          )|> 
          add_n() |>
          add_global_p() |>
          bold_p() |>  
          bold_labels() |>
          italicize_levels(),
        .header = "**{strata}**, N = {n}"
      )
  } else {
    mul<-dta_l |>
      lm(formula(paste(c(outs[i],"."),collapse="~")), 
         data = _) |> 
      tbl_regression(label = lab_sel(labels_all,vars),
                     show_single_row=colnames(dta_l)[sel],
                     estimate_fun = ~style_sigfig(.x,digits = 3),
                     pvalue_fun = ~style_pvalue(.x, digits = 3)
      )|> 
      add_n() |>
      add_global_p() |>
      bold_p() 
  }

  # Back transforming if flag set
  if (trans_back==TRUE){
    ls<-lapply(list(biv,mul), back_trans, outm = "log1p" ,sqrts = "pase_0",log1ps = "nihss_0")
  } else {ls<-list(biv,mul)}
  
  ## Merge
  biv_mul<-tbl_merge(
    tbls = ls, 
    tab_spanner = c("**Bivariate linear regression**", 
                    "**Multivariate linear regression**") 
  )
  
  bm_list[[i]]<-biv_mul
}

## =============================================================================
## Big merge
## =============================================================================

# Header if back transformed
if (trans_back==TRUE){tab_span<-c("**One month follow up [TRANS t/r]**", 
                                  "**Six months follow up [TRANS t/r]**")
} else {tab_span<-c("**One month follow up**", 
                    "**Six months follow up**")}

bm_16_tbl<-tbl_merge(
  tbls = bm_list, 
  tab_spanner = tab_span 
)

## =============================================================================
## Print
## =============================================================================

# File name depending onstratification, transformation and back transformation
if (print_tbl==TRUE){
fnm<-paste0("bm_16_tbl",lbl_x)
if (!is.null(strat_var)){fnm<-paste0(fnm,"_strat")}
if (trans_vars==TRUE){fnm<-paste0(fnm,"_trans")}
if (trans_back==TRUE){fnm<-paste0(fnm,"_back")}


bm_16_tbl_rtf <- file(paste0(fnm,".RTF"), "w")
writeLines(bm_16_tbl%>%as_gt()%>%as_rtf(), bm_16_tbl_rtf)
close(bm_16_tbl_rtf)

}