## =============================================================================
## Requirements
## =============================================================================

source("function_trans_cols.R")

if (trans_vars==TRUE){
  # If trans_vars flag is TRUE, transform specified variables
  dta<-trans_cols(dta_backup,sqrts=sqrt_vars,log1ps = log1p_vars_all)
} else {dta<-dta_backup}

library(dplyr)
library(gtsummary)

source("function_back_trans.R")

## =============================================================================
## Loop
## =============================================================================

bm_list<-list()

for (i in 1:length(outs)){
  
  dta_l<-dta|>
    dplyr::select(all_of(c("active_treat",vars,outs[i]))) # active_treat should be vector
  
  sel<-dta_l|>
    sapply(is.factor)
  
  ## Multivariate
  mul<-dta_l |>
    lm(formula(
      paste(c(paste(c(outs[i],paste(c("active_treat","pase_0"),collapse="*")),collapse="~"),"."),collapse="+")), 
      data = _)|> 
    tbl_regression(label = lab_sel(labels_all,c(vars,"active_treat")),
                   show_single_row=colnames(dta_l)[sel],
                   estimate_fun = ~style_sigfig(.x,digits = 3),
                   pvalue_fun = ~style_pvalue(.x, digits = 3))|> 
    add_n() |>
    add_global_p() |>
    bold_p() |>  
    bold_labels() |>
    italicize_levels()
  

  mul <- back_trans(mul, outm = "log1p" ,sqrts = "pase_0",log1ps = "nihss_0")


  bm_list[[i]]<-mul
}

## =============================================================================
## Big merge
## =============================================================================

bm_16_tbl <- tbl_merge(
  tbls = bm_list, 
  tab_spanner = c("**One month follow up**", 
                  "**Six months follow up**") 
)



library(aod)

for (i in 1:length(outs)){
  model<-dta |>
    dplyr::select(all_of(c("active_treat",vars,outs[i])))|>
    lm(formula(
      paste(c(paste(c(outs[i],paste(c("active_treat","pase_0"),collapse="*")),collapse="~"),"."),collapse="+")), 
      data = _)
  
  wt<-wald.test(Sigma = vcov(model), 
                b = coef(model), 
                Terms = model$rank # Rank gives number of coefficients. The interaction is the last.
  )
  print(wt)
}

## =============================================================================
## Print
## =============================================================================

# File name depending onstratification, transformation and back transformation
if (print_tbl==TRUE){
  fnm<-paste0("bm_16_tbl",lbl_x)
  if (!is.null(strat_var)){fnm<-paste0(fnm,"_strat")}
  if (trans_vars==TRUE){fnm<-paste0(fnm,"_trans")}
  if (trans_back==TRUE){fnm<-paste0(fnm,"_back")}
  
  
  bm_16_tbl_rtf <- file(paste0(fnm,".RTF"), "w")
  writeLines(bm_16_tbl%>%as_gt()%>%as_rtf(), bm_16_tbl_rtf)
  close(bm_16_tbl_rtf)
  
}
